@@ -7,13 +7,14 @@
 #include "node_geometry_util.hh"
 
 #include "UI_interface.hh"
+#include "UI_interface_layout.hh"
 
 namespace blender::nodes::node_geo_image_cc {
 
 static void node_declare(NodeDeclarationBuilder &b)
 {
   b.add_output<decl::Image>("Image").custom_draw([](CustomSocketDrawParams &params) {
-    uiLayoutSetAlignment(&params.layout, UI_LAYOUT_ALIGN_EXPAND);
+    params.layout.alignment_set(ui::LayoutAlign::Expand);
     uiTemplateID(&params.layout,
                  &params.C,
                  &params.node_ptr,
